:mod:`npdl.initializations`
===========================

.. automodule:: npdl.initialization

Initializers
------------

.. autosummary::

   Zero
   One
   Uniform
   Normal
   Orthogonal

Detailed Description
--------------------

.. autoclass:: Initializer
   :members:

.. autoclass:: Zero
   :members:

.. autoclass:: One
   :members:

.. autoclass:: Normal
   :members:

.. autoclass:: Uniform
   :members:

.. autoclass:: Orthogonal
   :members:

.. autoclass:: LecunUniform
   :members:

.. autoclass:: GlorotUniform
   :members:

.. autoclass:: GlorotNormal
   :members:

.. autoclass:: HeNormal
   :members:

.. autoclass:: HeUniform
   :members:

.. autoclass:: Orthogonal
   :members:

.. autofunction:: decompose_size

